# kawin

Python implementation of the Kampmann-Wagner Numerical (KWN) model to predict precipitate nucleation and growth behavior. This package couples with pycalphad to perform thermodynamic and kinetic calculations.

Notes
-----
There has been a lot of changes in the API. Please check the examples for further details.
If you still have issues setting up a simulation, feel free to open an issue.

Installation
------------
Installing through pip:

```
pip install kawin
```

Development version:

```
git clone https://github.com/materialsgenomefoundation/kawin
cd kawin
pip install -e .
```

Examples
--------
Examples on Jupyter notebooks can be found on [NBViewer](https://nbviewer.org/github/materialsgenomefoundation/kawin/tree/main/examples/).

Dependencies
------------
numpy, scipy, matplotlib, pycalphad
